@@ -71,9 +71,10 @@ int Query(char *dev)
 			;
 		else
 #endif
-			if (ioctl(fd, BLKGETSIZE, &array_size)==0)
-				larray_size = array_size<<9;
-			else larray_size = 0;
+			if (ioctl(fd, BLKGETSIZE, &array_size)==0) {
+				larray_size = array_size;
+				larray_size <<= 9;
+			} else larray_size = 0;
 	}
 	close(fd);
 
@@ -100,7 +101,7 @@ int Query(char *dev)
 		       dev, strerror(superrno));
 		break;
 	case 2:
-		printf("%s: is too small to be an md componenet.\n",
+		printf("%s: is too small to be an md component.\n",
 		       dev);
 		break;
 	case 3:
