@@ -29,7 +29,7 @@
 
 #include "mdadm.h"
 
-char Version[] = Name " - v0.8 -  4 April 2002\n";
+char Version[] = Name " - v1.4.0 - 29 Oct 2003\n";
 /*
  * File: ReadMe.c
  *
@@ -60,14 +60,14 @@ char Version[] = Name " - v0.8 -  4 April 2002\n";
 /*
  * mdadm has 6 major modes of operation:
  * 1/ Create
- *     This mode is used to create a new array with a superbock
+ *     This mode is used to create a new array with a superblock
  *     It can progress in several step create-add-add-run
  *     or it can all happen with one command
  * 2/ Assemble
  *     This mode is used to assemble the parts of a previously created
  *     array into an active array.  Components can be explicitly given
  *     or can be searched for.  mdadm (optionally) check that the components
- *     do form a bonafide array, and can, on request, fiddle superblock
+ *     do form a bona-fide array, and can, on request, fiddle superblock
  *     version numbers so as to assemble a faulty array.
  * 3/ Build
  *     This is for building legacy arrays without superblocks
@@ -86,7 +86,7 @@ char Version[] = Name " - v0.8 -  4 April 2002\n";
  *     This mode never exits but just monitors arrays and reports changes.
  */
 
-char short_options[]="-ABCDEFGQhVvbc:l:p:m:n:x:u:c:d:z:sarfRSow";
+char short_options[]="-ABCDEFGQhVvbc:l:p:m:n:x:u:c:d:z:U:sarfRSow1t";
 struct option long_options[] = {
     {"manage",    0, 0, '@'},
     {"misc",      0, 0, '#'},
@@ -105,6 +105,7 @@ struct option long_options[] = {
 	    
     /* after those will normally come the name of the md device */
     {"help",      0, 0, 'h'},
+    {"help-options",0,0,'h'},
     {"version",	  0, 0, 'V'},
     {"verbose",   0, 0, 'v'},
 
@@ -112,10 +113,12 @@ struct option long_options[] = {
     {"chunk",	  1, 0, 'c'},
     {"rounding",  1, 0, 'c'}, /* for linear, chunk is really a rounding number */
     {"level",     1, 0, 'l'}, /* 0,1,4,5,linear */
-    {"parity",    1, 0, 'p'}, /* {left,right}-{a,}symetric */
+    {"parity",    1, 0, 'p'}, /* {left,right}-{a,}symmetric */
     {"layout",    1, 0, 'p'},
     {"raid-disks",1, 0, 'n'},
+    {"raid-devices",1, 0, 'n'},
     {"spare-disks",1,0, 'x'},
+    {"spare-devices",1,0, 'x'},
     {"size"      ,1, 0, 'z'},
 
     /* For assemble */
@@ -124,6 +127,7 @@ struct option long_options[] = {
     {"config",    1, 0, 'c'},
     {"scan",      0, 0, 's'},
     {"force",	  0, 0, 'f'},
+    {"update",	  1, 0, 'U'},
     /* Management */
     {"add",       0, 0, 'a'},
     {"remove",    0, 0, 'r'},
@@ -136,13 +140,17 @@ struct option long_options[] = {
 
     /* For Detail/Examine */
     {"brief",	  0, 0, 'b'},
+    {"sparc2.2",  0, 0, 22},
+    {"test",      0, 0, 't'},
 
     /* For Follow/monitor */
     {"mail",      1, 0, 'm'},
     {"program",   1, 0, 'p'},
     {"alert",     1, 0, 'p'},
     {"delay",     1, 0, 'd'},
-    
+    {"daemonise", 0, 0, 'f'},
+    {"daemonize", 0, 0, 'f'},
+    {"oneshot",   0, 0, '1'},
     
     {0, 0, 0, 0}
 };
@@ -160,19 +168,24 @@ char Help[] =
 "       mdadm --misc options... devices\n"
 "       mdadm --monitor options...\n"
 "       mdadm device options...\n"
-" mdadm is used for building, manageing, and monitoring\n"
-"      Linux md devices (aka RAID arrays)\n"
-" For detail help on the above major modes use --help after the mode\n"
+" mdadm is used for building, managing, and monitoring\n"
+" Linux md devices (aka RAID arrays)\n"
+" For detailed help on the above major modes use --help after the mode\n"
 " e.g.\n"
 "         mdadm --assemble --help\n"
-"\n"
+" For general help on options use\n"
+"         mdadm --help-options\n"
+;
+
+char OptionHelp[] =
 "Any parameter that does not start with '-' is treated as a device name\n"
 "The first such name is often the name of an md device.  Subsequent\n"
 "names are often names of component devices."
 "\n"
 "Some common options are:\n"
-"  --help        -h   : This help message or, after above option,\n"
+"  --help        -h   : General help message or, after above option,\n"
 "                       mode specific help message\n"
+"  --help-options     : This help message\n"
 "  --version     -V   : Print version information for mdadm\n"
 "  --verbose     -v   : Be more verbose about what is happening\n"
 "  --brief       -b   : Be less verbose, more brief\n"
@@ -182,7 +195,7 @@ char Help[] =
 "  --build       -B   : Build a legacy array\n"
 "  --create      -C   : Create a new array\n"
 "  --detail      -D   : Display details of an array\n"
-"  --examine     -E   : Examine superblock on an array componenet\n"
+"  --examine     -E   : Examine superblock on an array component\n"
 "  --monitor     -F   : monitor (follow) some arrays\n"
 "  --query       -Q   : Display general information about how a\n"
 "                       device relates to the md driver\n"
@@ -191,12 +204,12 @@ char Help[] =
 "\n"
 " For create or build:\n"
 "  --chunk=      -c   : chunk size of kibibytes\n"
-"  --rounding=        : rounding factor for linear array (==chunck size)\n"
-"  --level=      -l   : raid level: 0,1,4,5,linear.  0 or linear for build\n"
-"  --paritiy=    -p   : raid5 parity algorith: {left,right}-{,a}symmetric\n"
+"  --rounding=        : rounding factor for linear array (==chunk size)\n"
+"  --level=      -l   : raid level: 0,1,4,5,linear,mp.  0 or linear for build\n"
+"  --parity=     -p   : raid5 parity algorithm: {left,right}-{,a}symmetric\n"
 "  --layout=          : same as --parity\n"
-"  --raid-disks= -n   : number of active devices in array\n"
-"  --spare-disks= -x  : number of spares (eXtras) devices in initial array\n"
+"  --raid-devices= -n : number of active devices in array\n"
+"  --spare-devices= -x: number of spares (eXtras) devices in initial array\n"
 "  --size=       -z   : Size (in K) of each drive in RAID1/4/5 - optional\n"
 "  --force       -f   : Honour devices as listed on command line.  Don't\n"
 "                     : insert a missing drive for RAID5.\n"
@@ -209,6 +222,7 @@ char Help[] =
 "  --config=     -c   : config file\n"
 "  --scan        -s   : scan config file for missing information\n"
 "  --force       -f   : Assemble the array even if some superblocks appear out-of-date\n"
+"  --update=     -U   : Update superblock: one of sparc2.2, super-minor or summaries\n"
 "\n"
 " For detail or examine:\n"
 "  --brief       -b   : Just print device name and UUID\n"
@@ -225,7 +239,7 @@ char Help[] =
 "  --fail        -f   : mark subsequent devices a faulty\n"
 "  --set-faulty       : same as --fail\n"
 "  --run         -R   : start a partially built array\n"
-"  --stop        -S   : deactive array, releasing all resources\n"
+"  --stop        -S   : deactivate array, releasing all resources\n"
 "  --readonly    -o   : mark array as readonly\n"
 "  --readwrite   -w   : mark array as readwrite\n"
 "  --zero-superblock  : erase the MD superblock from a device.\n"
@@ -233,18 +247,18 @@ char Help[] =
 */
 
 char Help_create[] =
-"Usage:  mdadm --create device -chunk=X --level=Y --raid-disks=Z devices\n"
+"Usage:  mdadm --create device -chunk=X --level=Y --raid-devices=Z devices\n"
 "\n"
-" This usage will initialise a new md array and associate some\n"
-" devices with it.  If enough devices are given to complete the array,\n"
-" the array will be activated.  Otherwise it will be left inactive\n"
-" to be completed and activated by subsequent management commands.\n"
+" This usage will initialise a new md array, associate some\n"
+" devices with it, and activate the array.   In order to create an\n"
+" array with some devices missing, use the special word 'missing' in\n"
+" place of the relevant device name.\n"
 "\n"
-" As devices are added, they are checked to see if they already contain\n"
+" Before devices are added, they are checked to see if they already contain\n"
 " raid superblocks or filesystems.  They are also checked to see if\n"
 " the variance in device size exceeds 1%.\n"
-" If any discrepancy is found, the array will not automatically\n"
-" be run, though the presence of a '--run' can override this\n"
+" If any discrepancy is found, the user will be prompted for confirmation\n"
+" before the array is created.  The presence of a '--run' can override this\n"
 " caution.\n"
 "\n"
 " If the --size option is given then only that many kilobytes of each\n"
@@ -255,23 +269,23 @@ char Help_create[] =
 "\n"
 " Options that are valid with --create (-C) are:\n"
 "  --chunk=      -c   : chunk size of kibibytes\n"
-"  --rounding=        : rounding factor for linear array (==chunck size)\n"
+"  --rounding=        : rounding factor for linear array (==chunk size)\n"
 "  --level=      -l   : raid level: 0,1,4,5,linear,multipath and synonyms\n"
-"  --paritiy=    -p   : raid5 parity algorith: {left,right}-{,a}symmetric\n"
+"  --parity=     -p   : raid5 parity algorithm: {left,right}-{,a}symmetric\n"
 "  --layout=          : same as --parity\n"
-"  --raid-disks= -n   : number of active devices in array\n"
-"  --spare-disks= -x  : number of spares (eXtras) devices in initial array\n"
+"  --raid-devices= -n : number of active devices in array\n"
+"  --spare-devices= -x: number of spares (eXtras) devices in initial array\n"
 "  --size=       -z   : Size (in K) of each drive in RAID1/4/5 - optional\n"
 "  --force       -f   : Honour devices as listed on command line.  Don't\n"
 "                     : insert a missing drive for RAID5.\n"
-"   --run             : insist of running the array even if not all\n"
+"  --run         -R   : insist of running the array even if not all\n"
 "                     : devices are present or some look odd.\n"
-"   --readonly        : start the array readonly - not supported yet.\n"
+"  --readonly    -o   : start the array readonly - not supported yet.\n"
 "\n"
 ;
 
 char Help_build[] =
-"Usage:  mdadm --build device -chunk=X --level=Y --raid-disks=Z devices\n"
+"Usage:  mdadm --build device -chunk=X --level=Y --raid-devices=Z devices\n"
 "\n"
 " This usage is similar to --create.  The difference is that it creates\n"
 " a legacy array without a superblock.  With these arrays there is no\n"
@@ -283,9 +297,9 @@ char Help_build[] =
 " All devices must be listed and the array will be started once complete.\n"
 " Options that are valid with --build (-B) are:\n"
 "  --chunk=      -c   : chunk size of kibibytes\n"
-"  --rounding=        : rounding factor for linear array (==chunck size)\n"
+"  --rounding=        : rounding factor for linear array (==chunk size)\n"
 "  --level=      -l   : 0, raid0, or linear\n"
-"  --raid-disks= -n   : number of active devices in array\n"
+"  --raid-devices= -n   : number of active devices in array\n"
 ;
 
 char Help_assemble[] =
@@ -331,6 +345,7 @@ char Help_assemble[] =
 "                       for a full array are present\n"
 "  --force       -f   : Assemble the array even if some superblocks appear\n"
 "                     : out-of-date.  This involves modifying the superblocks.\n"
+"  --update=     -U   : Update superblock: one of sparc2.2, super-minor or summaries\n"
 ;
 
 char Help_manage[] =
@@ -348,7 +363,7 @@ char Help_manage[] =
 "  --fail        -f   : mark subsequent devices a faulty\n"
 "  --set-faulty       : same as --fail\n"
 "  --run         -R   : start a partially built array\n"
-"  --stop        -S   : deactive array, releasing all resources\n"
+"  --stop        -S   : deactivate array, releasing all resources\n"
 "  --readonly    -o   : mark array as readonly\n"
 "  --readwrite   -w   : mark array as readwrite\n"
 ;
@@ -365,12 +380,13 @@ char Help_misc[] =
 "  --query       -Q   : Display general information about how a\n"
 "                       device relates to the md driver\n"
 "  --detail      -D   : Display details of an array\n"
-"  --examine     -E   : Examine superblock on an array componenet\n"
+"  --examine     -E   : Examine superblock on an array component\n"
 "  --zero-superblock  : erase the MD superblock from a device.\n"
 "  --run         -R   : start a partially built array\n"
-"  --stop        -S   : deactive array, releasing all resources\n"
+"  --stop        -S   : deactivate array, releasing all resources\n"
 "  --readonly    -o   : mark array as readonly\n"
 "  --readwrite   -w   : mark array as readwrite\n"
+"  --test        -t   : exit status 0 if ok, 1 if degrade, 2 if dead, 4 if missing\n"
 ;
 
 char Help_monitor[] =
@@ -392,6 +408,8 @@ char Help_monitor[] =
 "  --delay=      -d   : seconds of delay between polling state. default=60\n"
 "  --config=     -c   : specify a different config file\n"
 "  --scan        -s   : find mail-address/program in config file\n"
+"  --daemonise   -f   : Fork and continue in child, parent exits\n"
+"  --oneshot     -1   : Check for degraded arrays, then exit\n"
 ;
 
 
@@ -418,7 +436,7 @@ char Help_config[] =
 " array.  The identity can be given as a UUID with a word starting 'uuid=', or\n"
 " as a minor-number stored in the superblock using 'super-minor=', or as a list\n"
 " of devices.  This is given as a comma separated list of names, possibly\n"
-" containing wildcards, preceeded by 'devices='. If multiple critea are given,\n"
+" containing wildcards, preceded by 'devices='. If multiple critea are given,\n"
 " than a device must match all of them to be considered.\n"
 "\n"
 " A mailaddr line starts with the word 'mailaddr' and should contain exactly\n"
