@@ -78,11 +78,13 @@ int main(int argc, char *argv[])
 	int verbose = 0;
 	int brief = 0;
 	int force = 0;
+	int test = 0;
 
 	char *mailaddr = NULL;
 	char *program = NULL;
 	int delay = 0;
 	int daemonise = 0;
+	int oneshot = 0;
 
 	int mdfd = -1;
 
@@ -320,6 +322,12 @@ int main(int argc, char *argv[])
 					optarg);
 				exit(2);
 			}
+			if (raiddisks == 1 &&  !force) {
+				fprintf(stderr, Name ": '1' is an unusual number of drives for an array, so it is probably\n"
+					"     a mistake.  If you really mean it you will need to specify --force before\n"
+					"     setting the number of drives.\n");
+				exit(2);
+			}
 			ident.raid_disks = raiddisks;
 			continue;
 
@@ -341,6 +349,7 @@ int main(int argc, char *argv[])
 				exit(2);
 			}
 			continue;
+		case O(BUILD,'f'): /* force honouring '-n 1' */
 		case O(CREATE,'f'): /* force honouring of device list */
 		case O(ASSEMBLE,'f'): /* force assembly */
 		case O(MISC,'f'): /* force zero */
@@ -389,7 +398,9 @@ int main(int argc, char *argv[])
 			if (strcmp(update, "sparc2.2")==0) continue;
 			if (strcmp(update, "super-minor") == 0)
 				continue;
-			fprintf(stderr, Name ": '--update %s' invalid.  Only 'sparc2.2' or 'super-minor' supported\n",update);
+			if (strcmp(update, "summaries")==0)
+				continue;
+			fprintf(stderr, Name ": '--update %s' invalid.  Only 'sparc2.2', 'super-minor' or 'summaries' supported\n",update);
 			exit(2);
 
 		case O(ASSEMBLE,'c'): /* config file */
@@ -441,7 +452,9 @@ int main(int argc, char *argv[])
 		case O(MONITOR,'f'): /* daemonise */
 			daemonise = 1;
 			continue;
-			
+		case O(MONITOR,'1'): /* oneshot */
+			oneshot = 1;
+			continue;
 
 			/* now the general management options.  Some are applicable
 			 * to other modes. None have arguments.
@@ -507,6 +520,9 @@ int main(int argc, char *argv[])
 			}
 			devmode = opt;
 			continue;
+		case O(MISC,'t'):
+			test = 1;
+			continue;
 
 		case O(MISC, 22):
 			if (devmode != 'E') {
@@ -673,7 +689,7 @@ int main(int argc, char *argv[])
 							continue;
 						}
 						if (devmode == 'D')
-							rv |= Detail(name, !verbose);
+							rv |= Detail(name, !verbose, test);
 						else if (devmode=='S') {
 							mdfd = open_mddev(name);
 							if (mdfd >= 0)
@@ -689,7 +705,7 @@ int main(int argc, char *argv[])
 			for (dv=devlist ; dv; dv=dv->next) {
 				switch(dv->disposition) {
 				case 'D':
-					rv |= Detail(dv->devname, brief); continue;
+					rv |= Detail(dv->devname, brief, test); continue;
 				case 'K': /* Zero superblock */
 					rv |= Kill(dv->devname, force); continue;
 				case 'Q':
@@ -717,7 +733,7 @@ int main(int argc, char *argv[])
 			break;
 		}
 		rv= Monitor(devlist, mailaddr, program,
-			    delay?delay:60, daemonise, scan, configfile);
+			    delay?delay:60, daemonise, scan, oneshot, configfile);
 		break;
 	}
 	exit(rv);
