@@ -96,6 +96,7 @@ typedef struct mddev_ident_s {
 				 */
 	int level;		/* -10 if not set */
 	int raid_disks;		/* -1 if not set */
+	int spare_disks;	/* -1 if not set */
 	char *spare_group;
 	struct mddev_ident_s *next;
 } *mddev_ident_t;
@@ -159,16 +160,16 @@ extern int Build(char *mddev, int mdfd, int chunk, int level,
 
 
 extern int Create(char *mddev, int mdfd,
-		  int chunk, int level, int layout, int size, int raiddisks, int sparedisks,
+		  int chunk, int level, int layout, unsigned long size, int raiddisks, int sparedisks,
 		  int subdevs, mddev_dev_t devlist,
 		  int runstop, int verbose, int force);
 
-extern int Detail(char *dev, int brief);
+extern int Detail(char *dev, int brief, int test);
 extern int Query(char *dev);
 extern int Examine(mddev_dev_t devlist, int brief, int scan, int SparcAdjust);
 extern int Monitor(mddev_dev_t devlist,
 		   char *mailaddr, char *alert_cmd,
-		   int period, int daemonise, int scan,
+		   int period, int daemonise, int scan, int oneshot,
 		   char *config);
 
 extern int Kill(char *dev, int force);
